@@ -55,7 +55,7 @@ sub source {
     my $rule_target = qr/(?:$plain|$curly|$parentheses)/;
 
     $self->tag('no-dh-sequencer')
-      unless $contents =~ /^\%:[^ \t]*\n\t+dh[ \t]+$rule_target/m
+      unless $contents =~ /^[^:]+:[^ \t]*\n\t+dh[ \t]+$rule_target/m
       || $contents =~ m{^\s*include\s+/usr/share/cdbs/1/class/hlibrary.mk\s*$}m
       || $contents =~ m{\bDEB_CABAL_PACKAGE\b};
 
