@@ -166,6 +166,8 @@ Hash with active jobs.
 
 =item C<saved_direct_dependencies>
 
+=item C<saved_direct_reliants>
+
 =item C<saved_spelling_exceptions>
 
 =item C<shared_storage>
@@ -199,6 +201,7 @@ has extra_coll => (is => 'rw', default => sub { [] });
 has queue => (is => 'rw', default => sub { [] });
 
 has saved_direct_dependencies => (is => 'rw', default => sub { {} });
+has saved_direct_reliants => (is => 'rw', default => sub { {} });
 has saved_spelling_exceptions => (is => 'rw', default => sub { {} });
 
 has shared_storage => (is => 'rw', default => sub { {} });
@@ -467,7 +470,7 @@ sub unpack {
         };
     }
 
-    return 0
+    return 1
       unless %worklists;
 
     $self->worktable(\%worklists);
@@ -571,7 +574,7 @@ sub coll_hook {
             "Collection script $coll for $procid done ($tres)");
         $OUTPUT->perf_log("$procid,coll/$coll,${raw_res}");
 
-        return 0;
+        return 1;
     }
 
     # unknown event
@@ -633,6 +636,33 @@ sub process {
                 die $err if not ref $err or $err->errno != ENOENT;
             }
 
+            my %alias = %{$TAGS->{profile}->aliases};
+
+            # treat renamed tags in overrides
+            for my $tagname (keys %{$declared_overrides}) {
+
+                # use new name if tag was renamed
+                my $current = $alias{$tagname};
+
+                next
+                  unless defined $current;
+
+                unless ($current eq $tagname) {
+
+                    $processable->tag('renamed-tag',
+                        "$tagname => $current at line "
+                          .$declared_overrides->{$tagname}{$_}{line})
+                      for keys %{$declared_overrides->{$tagname}};
+
+                    $declared_overrides->{$current} //= {};
+                    $declared_overrides->{$current}{$_}
+                      = $declared_overrides->{$tagname}{$_}
+                      for keys %{$declared_overrides->{$tagname}};
+
+                    delete $declared_overrides->{$tagname};
+                }
+            }
+
             push(@found, @{$processable->found});
 
             # remove found tags from Processable
@@ -1140,6 +1170,56 @@ sub direct_dependencies {
     return $self->saved_direct_dependencies;
 }
 
+=item direct_reliants (PROC)
+
+If PROC is a part of the underlying processable group, this method
+returns a listref containing all the packages in the group that rely
+on PROC.  If PROC is not a part of the group, this returns undef.
+
+Note: Only strong dependencies (Pre-Depends and Depends) are
+considered.
+
+Note: Self-dependencies (if any) are I<not> included in the result.
+
+=cut
+
+# sub direct_reliants Needs-Info <>
+sub direct_reliants {
+    my ($self, $processable) = @_;
+
+    unless (keys %{$self->saved_direct_reliants}) {
+
+        my @processables = $self->get_processables('binary');
+        push @processables, $self->get_processables('udeb');
+
+        my %reliants;
+        foreach my $that (@processables) {
+
+            my @specific;
+            foreach my $this (@processables) {
+
+                # Ignore self deps - we have checks for that and it
+                # will just end up complicating "correctness" of
+                # otherwise simple checks.
+                next
+                  if $this->name eq $that->name;
+
+                my $relation = $this->relation('strong');
+                push @specific, $this
+                  if $relation->implies($that->name);
+            }
+            $reliants{$that->name} = \@specific;
+        }
+
+        $self->saved_direct_reliants(\%reliants);
+    }
+
+    return $self->saved_direct_reliants->{$processable->name}
+      if $processable;
+
+    return $self->saved_direct_reliants;
+}
+
 =item $ginfo->type
 
 Return the type of this collect object (which is the string 'group').
